@@ -41,7 +41,6 @@
 #include <X11/XKBlib.h>
 #endif
 
-#include "gdkalias.h"
 #include "gdk.h"
 
 #include "gdkx.h"
@@ -50,6 +49,7 @@
 #include "gdkintl.h"
 #include "gdkregion-generic.h"
 #include "gdkinputprivate.h"
+#include "gdkalias.h"
 
 typedef struct _GdkPredicate  GdkPredicate;
 typedef struct _GdkErrorTrap  GdkErrorTrap;
@@ -736,7 +736,7 @@ _gdk_region_get_xrectangles (GdkRegion   *region,
  * gdk_x11_grab_server()/gdk_x11_ungrab_server() calls can be nested.
  **/ 
 void
-gdk_x11_grab_server ()
+gdk_x11_grab_server (void)
 {
   gdk_x11_display_grab (gdk_display_get_default ());
 }
@@ -748,7 +748,7 @@ gdk_x11_grab_server ()
  * gdk_x11_grab_server(). 
  **/
 void
-gdk_x11_ungrab_server ()
+gdk_x11_ungrab_server (void)
 {
   gdk_x11_display_ungrab (gdk_display_get_default ());
 }
@@ -797,4 +797,5 @@ gdk_x11_get_default_xdisplay (void)
   return GDK_DISPLAY_XDISPLAY (gdk_display_get_default ());
 }
 
-
+#define __GDK_MAIN_X11_C__
+#include "gdkaliasdef.c"
