@@ -29,7 +29,6 @@
 #include "gdkconfig.h"
 #include <math.h>
 
-#include "gtkalias.h"
 #include "gdk/gdkkeysyms.h"
 #include "gtkcolorsel.h"
 #include "gtkhsv.h"
@@ -60,12 +59,16 @@
 #include "gtkimage.h"
 #include "gtkstock.h"
 #include "gtkaccessible.h"
+#include "gtkalias.h"
 
 #include <string.h>
 
 #ifdef GDK_WINDOWING_X11
 #include <X11/Xlib.h>
 #include "x11/gdkx.h"
+#elif defined GDK_WINDOWING_WIN32
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
 #endif
 
 /* Number of elements in the custom palatte */
@@ -1311,7 +1314,7 @@ key_press (GtkWidget   *invisible,
       
       return TRUE;
 
-#ifdef GDK_WINDOWING_X11
+#if defined GDK_WINDOWING_X11 || defined GDK_WINDOWING_WIN32
     case GDK_Up:
     case GDK_KP_Up:
       dy = state == GDK_MOD1_MASK ? -BIG_STEP : -1;
@@ -1340,6 +1343,12 @@ key_press (GtkWidget   *invisible,
 #ifdef GDK_WINDOWING_X11
   XWarpPointer (gdk_x11_display_get_xdisplay (display),
 		None, None, 0, 0, 0, 0, dx, dy);
+#elif defined GDK_WINDOWING_WIN32
+  {
+    POINT point;
+    if (GetCursorPos (&point))
+      SetCursorPos (point.x + dx, point.y + dy);
+  }
 #endif
   
   return TRUE;
@@ -1704,8 +1713,8 @@ update_color (GtkColorSelection *colorsel)
   g_signal_emit (colorsel, color_selection_signals[COLOR_CHANGED], 0);
   
   g_object_freeze_notify (G_OBJECT (colorsel));
-  g_object_notify (G_OBJECT (colorsel), "current_color");
-  g_object_notify (G_OBJECT (colorsel), "current_alpha");
+  g_object_notify (G_OBJECT (colorsel), "current-color");
+  g_object_notify (G_OBJECT (colorsel), "current-alpha");
   g_object_thaw_notify (G_OBJECT (colorsel));
   
   g_object_unref (colorsel);
@@ -2218,7 +2227,7 @@ gtk_color_selection_set_has_opacity_control (GtkColorSelection *colorsel,
 	}
       color_sample_draw_samples (colorsel);
       
-      g_object_notify (G_OBJECT (colorsel), "has_opacity_control");
+      g_object_notify (G_OBJECT (colorsel), "has-opacity-control");
     }
 }
 
@@ -2268,7 +2277,7 @@ gtk_color_selection_set_has_palette (GtkColorSelection *colorsel,
       else
 	gtk_widget_hide (priv->palette_frame);
       
-      g_object_notify (G_OBJECT (colorsel), "has_palette");
+      g_object_notify (G_OBJECT (colorsel), "has-palette");
     }
 }
 
@@ -2850,3 +2859,7 @@ make_all_relations (AtkObject *atk_obj,
   make_control_relations (atk_obj, priv->green_spinbutton);
   make_control_relations (atk_obj, priv->blue_spinbutton);
 }
+
+#define __GTK_COLOR_SELECTION_C__
+#include "gtkaliasdef.c"
+
