@@ -33,7 +33,6 @@
 #include <config.h>
 #include <string.h>
 
-#include "gtkalias.h"
 #include "gtkarrow.h"
 #include "gtklabel.h"
 #include "gtklist.h"
@@ -48,8 +47,9 @@
 #include "gtkcombo.h"
 #include "gtkframe.h"
 #include "gtkintl.h"
+#include "gtkalias.h"
 
-const gchar *gtk_combo_string_key = "gtk-combo-string-value";
+const gchar gtk_combo_string_key[] = "gtk-combo-string-value";
 
 #define COMBO_LIST_MAX_HEIGHT	(400)
 #define	EMPTY_LIST_HEIGHT	(15)
@@ -1065,12 +1065,12 @@ gtk_combo_set_value_in_list (GtkCombo * combo, gboolean val, gboolean ok_if_empt
   if (combo->value_in_list != val)
     {
        combo->value_in_list = val;
-  g_object_notify (G_OBJECT (combo), "value_in_list");
+  g_object_notify (G_OBJECT (combo), "value-in-list");
     }
   if (combo->ok_if_empty != ok_if_empty)
     {
        combo->ok_if_empty = ok_if_empty;
-  g_object_notify (G_OBJECT (combo), "allow_empty");
+  g_object_notify (G_OBJECT (combo), "allow-empty");
     }
   g_object_thaw_notify (G_OBJECT (combo));
 }
@@ -1084,7 +1084,7 @@ gtk_combo_set_case_sensitive (GtkCombo * combo, gboolean val)
   if (combo->case_sensitive != val) 
     {
   combo->case_sensitive = val;
-  g_object_notify (G_OBJECT (combo), "case_sensitive");
+  g_object_notify (G_OBJECT (combo), "case-sensitive");
     }
 }
 
@@ -1097,7 +1097,7 @@ gtk_combo_set_use_arrows (GtkCombo * combo, gboolean val)
   if (combo->use_arrows != val) 
     {
   combo->use_arrows = val;
-  g_object_notify (G_OBJECT (combo), "enable_arrow_keys");
+  g_object_notify (G_OBJECT (combo), "enable-arrow-keys");
     }
 }
 
@@ -1111,12 +1111,12 @@ gtk_combo_set_use_arrows_always (GtkCombo * combo, gboolean val)
     {
        g_object_freeze_notify (G_OBJECT (combo));
   combo->use_arrows_always = val;
-       g_object_notify (G_OBJECT (combo), "enable_arrows_always");
+       g_object_notify (G_OBJECT (combo), "enable-arrows-always");
 
        if (combo->use_arrows != TRUE) 
          {
   combo->use_arrows = TRUE;
-  g_object_notify (G_OBJECT (combo), "enable_arrow_keys");
+  g_object_notify (G_OBJECT (combo), "enable-arrow-keys");
          }
   g_object_thaw_notify (G_OBJECT (combo));
     }
@@ -1254,3 +1254,6 @@ gtk_combo_get_property (GObject         *object,
     }
    
 }
+
+#define __GTK_SMART_COMBO_C__
+#include "gtkaliasdef.c"
