@@ -53,6 +53,7 @@
 #undef GTK_DISABLE_DEPRECATED
 #include	"gtk/gtkoptionmenu.h"
 #define GTK_DISABLE_DEPRECATED
+#include 	"gtkalias.h"
 
 /* --- defines --- */
 #define		ITEM_FACTORY_STRING	((gchar*) item_factory_string)
@@ -81,7 +82,7 @@ static void	gtk_item_factory_finalize		(GObject	      *object);
 /* --- static variables --- */
 static GtkItemFactoryClass *gtk_item_factory_class = NULL;
 static gpointer          parent_class = NULL;
-static const gchar	*item_factory_string = "Gtk-<ItemFactory>";
+static const gchar	 item_factory_string[] = "Gtk-<ItemFactory>";
 static GMemChunk	*ifactory_item_chunks = NULL;
 static GMemChunk	*ifactory_cb_data_chunks = NULL;
 static GQuark		 quark_popup_data = 0;
@@ -1597,3 +1598,6 @@ gtk_item_factory_set_translate_func (GtkItemFactory      *ifactory,
   ifactory->translate_data = data;
   ifactory->translate_notify = notify;
 }
+
+#define __GTK_ITEM_FACTORY_C__
+#include "gtkaliasdef.c"
