@@ -28,13 +28,13 @@
 #include <config.h>
 #include <stdio.h>
 #include <math.h>
-#include "gtkalias.h"
 #include "gtkintl.h"
 #include "gtkmain.h"
 #include "gtkmarshalers.h"
 #include "gtkrange.h"
 #include "gtkintl.h"
 #include "gtkscrollbar.h"
+#include "gtkalias.h"
 
 #define SCROLL_INITIAL_DELAY 250  /* must hold button this long before ... */
 #define SCROLL_LATER_DELAY   100  /* ... it starts repeating at this rate  */
@@ -134,7 +134,7 @@ static void gtk_range_style_set      (GtkWidget        *widget,
 static void update_slider_position   (GtkRange	       *range,
 				      gint              mouse_x,
 				      gint              mouse_y);
-
+static void stop_scrolling           (GtkRange         *range);
 
 /* Range methods */
 
@@ -519,7 +519,7 @@ gtk_range_set_update_policy (GtkRange      *range,
   if (range->update_policy != policy)
     {
       range->update_policy = policy;
-      g_object_notify (G_OBJECT (range), "update_policy");
+      g_object_notify (G_OBJECT (range), "update-policy");
     }
 }
 
@@ -890,6 +890,8 @@ gtk_range_unmap (GtkWidget *widget)
 {
   GtkRange *range = GTK_RANGE (widget);
     
+  stop_scrolling (range);
+
   gdk_window_hide (range->event_window);
 
   GTK_WIDGET_CLASS (parent_class)->unmap (widget);
@@ -1361,7 +1363,8 @@ update_slider_position (GtkRange *range,
                  &handled);
 }
 
-static void stop_scrolling (GtkRange *range)
+static void 
+stop_scrolling (GtkRange *range)
 {
   range_grab_remove (range);
   gtk_range_remove_step_timer (range);
@@ -2544,3 +2547,6 @@ gtk_range_remove_update_timer (GtkRange *range)
       range->update_timeout_id = 0;
     }
 }
+
+#define __GTK_RANGE_C__
+#include "gtkaliasdef.c"
