@@ -565,6 +565,28 @@ gtk_im_context_xim_finalize (GObject *obj)
 
   context_xim->finalizing = TRUE;
 
+  if (context_xim->im_info && !context_xim->im_info->ics->next) 
+    {
+      GdkDisplay *display;
+      
+      display = gdk_screen_get_display (context_xim->im_info->screen);
+      if (context_xim->im_info->reconnecting) 
+	XUnregisterIMInstantiateCallback (GDK_DISPLAY_XDISPLAY (display),
+					  NULL, NULL, NULL,
+					  xim_instantiate_callback,
+					  (XPointer)context_xim->im_info);
+      else
+	{
+	  XIMCallback im_destroy_callback;
+
+	  im_destroy_callback.client_data = NULL;
+	  im_destroy_callback.callback = NULL;
+	  XSetIMValues (context_xim->im_info->im,
+			XNDestroyCallback, &im_destroy_callback,
+			NULL);
+	}
+    }
+
   set_ic_client_window (context_xim, NULL);
 
   g_free (context_xim->locale);
@@ -810,7 +832,7 @@ gtk_im_context_xim_set_cursor_location (GtkIMContext *context,
 
   preedit_attr = XVaCreateNestedList (0,
 				      XNSpotLocation, &spot,
-				      0);
+				      NULL);
   XSetICValues (ic,
 		XNPreeditAttributes, preedit_attr,
 		NULL);
@@ -857,7 +879,7 @@ gtk_im_context_xim_reset (GtkIMContext *context)
 
   preedit_attr = XVaCreateNestedList(0,
                                      XNPreeditState, &preedit_state,
-                                     0);
+                                     NULL);
   if (!XGetICValues(ic,
                     XNPreeditAttributes, preedit_attr,
                     NULL))
@@ -869,7 +891,7 @@ gtk_im_context_xim_reset (GtkIMContext *context)
 
   preedit_attr = XVaCreateNestedList(0,
                                      XNPreeditState, preedit_state,
-                                     0);
+                                     NULL);
   if (have_preedit_state)
     XSetICValues(ic,
 		 XNPreeditAttributes, preedit_attr,
